@@ -45,7 +45,7 @@ def make_usage_message():
            -U file Upload specified commands file (presently no checks).
            -i changes
                    Upload a commands file to remove files listed in .changes.
-         Supported commands: mv, rm
+         Supported commands: cancel, reschedule, rm
            (No paths or command-line options allowed on ftp-master.)
         """).format(progname=dputhelper.get_progname(sys.argv))
     return text
