@@ -17,7 +17,6 @@ import textwrap
 import types
 import unittest.mock
 
-import pkg_resources
 import testscenarios
 import testtools
 import testtools.matchers
@@ -29,14 +28,16 @@ from .helper import (
         EXIT_STATUS_FAILURE,
         EXIT_STATUS_SUCCESS,
         FakeSystemExit,
+        make_fake_distribution,
         make_options_namespace,
+        make_unique_slug,
+        patch_importlib_metadata_distribution,
         patch_os_environ,
         patch_os_getuid,
         patch_os_isatty,
         patch_pwd_getpwuid,
         patch_sys_argv,
         patch_system_interfaces,
-        make_unique_slug,
         )
 from .test_changesfile import (
         make_changes_file_path,
@@ -60,7 +61,6 @@ from .test_configfile import (
 from .test_dputhelper import (
         patch_get_username_from_system,
         patch_getopt,
-        patch_pkg_resources_get_distribution,
         )
 
 
@@ -109,6 +109,16 @@ def patch_import_upload_functions(testcase):
     func_patcher.start()
     testcase.addCleanup(func_patcher.stop)
 
+
+def patch_distribution(testcase):
+    """ Patch the “dput” installed distribution for the `testcase`. """
+    testcase.fake_distribution = make_fake_distribution(
+            name="dput",
+            version=getattr(testcase, 'dput_version', None),
+    )
+    patch_importlib_metadata_distribution(
+            testcase, fake_distribution=testcase.fake_distribution)
+
 
 class make_usage_message_TestCase(testtools.TestCase):
     """ Test cases for `make_usage_message` function. """
@@ -1022,7 +1032,7 @@ class parse_commandline_BaseTestCase(
         self.set_files_to_upload()
 
         self.patch_make_usage_message()
-        self.patch_distribution()
+        patch_distribution(self)
         patch_get_login_for_host(self)
         patch_verify_config_upload_methods(self)
 
@@ -1059,14 +1069,6 @@ class parse_commandline_BaseTestCase(
         func_patcher.start()
         self.addCleanup(func_patcher.stop)
 
-    def patch_distribution(self):
-        """ Patch the Python distribution for this test case. """
-        self.fake_distribution = unittest.mock.MagicMock(
-                pkg_resources.Distribution)
-        if hasattr(self, 'dput_version'):
-            self.fake_distribution.version = self.dput_version
-        patch_pkg_resources_get_distribution(self)
-
     def set_expected_args(self):
         """ Set the `expected_args` collection for this test case. """
         if not hasattr(self, 'expected_args'):
@@ -1658,7 +1660,7 @@ class main_TestCase(
         self.set_test_args()
 
         self.patch_make_usage_message()
-        self.patch_distribution()
+        patch_distribution(self)
 
         self.options_defaults = dict(
                 dput.dput.parse_commandline.options_defaults)
@@ -1705,14 +1707,6 @@ class main_TestCase(
         func_patcher.start()
         self.addCleanup(func_patcher.stop)
 
-    def patch_distribution(self):
-        """ Patch the Python distribution for this test case. """
-        self.fake_distribution = unittest.mock.MagicMock(
-                pkg_resources.Distribution)
-        if hasattr(self, 'dput_version'):
-            self.fake_distribution.version = self.dput_version
-        patch_pkg_resources_get_distribution(self)
-
     def set_fake_options(self, options_mapping=None):
         """ Set the `fake_options` object, updated with `options_mapping`. """
         if options_mapping is None:
